@@ -21,6 +21,7 @@
  */
 
 #include "kconfigdialogmanager.h"
+#include "kconfigwidgets_debug.h"
 
 #include <QComboBox>
 #include <QGroupBox>
@@ -210,14 +211,12 @@ void KConfigDialogManager::setupWidget(QWidget *widget, KConfigSkeletonItem *ite
             QObjectList children = gb->children();
             children.removeAll(gb->layout());
             const QList<QAbstractButton *> buttons = gb->findChildren<QAbstractButton *>();
-            if (children.count() == buttons.count()) {
-                bool allAutoExclusive = true;
-                foreach(QAbstractButton *button, buttons) {
-                    allAutoExclusive = allAutoExclusive && button->autoExclusive();
-                }
-                if (allAutoExclusive) {
-                    d->allExclusiveGroupBoxes << widget;
-                }
+            bool allAutoExclusiveDirectChildren = true;
+            foreach(QAbstractButton *button, buttons) {
+                allAutoExclusiveDirectChildren = allAutoExclusiveDirectChildren && button->autoExclusive() && button->parent() == gb;
+            }
+            if (allAutoExclusiveDirectChildren) {
+                d->allExclusiveGroupBoxes << widget;
             }
         }
     }
@@ -291,7 +290,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
                                 }
                             }
                         } else {
-                            qWarning() << "Don't know how to monitor widget '" << childWidget->metaObject()->className() << "' for changes!";
+                            qCWarning(KCONFIG_WIDGETS_LOG) << "Don't know how to monitor widget '" << childWidget->metaObject()->className() << "' for changes!";
                         }
                     } else {
                         connect(childWidget, propertyChangeSignal,
@@ -313,7 +312,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
                     d->insideGroupBox = true;
                 }
             } else {
-                qWarning() << "A widget named '" << widgetName << "' was found but there is no setting named '" << configId << "'";
+                qCWarning(KCONFIG_WIDGETS_LOG) << "A widget named '" << widgetName << "' was found but there is no setting named '" << configId << "'";
             }
         } else if (QLabel *label = qobject_cast<QLabel *>(childWidget)) {
             QWidget *buddy = label->buddy();
@@ -336,7 +335,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
 //       {
 //         if ((!d->insideGroupBox || !qobject_cast<QRadioButton*>(childWidget)) &&
 //             !qobject_cast<QGroupBox*>(childWidget) &&!qobject_cast<QTabWidget*>(childWidget) )
-//           qDebug() << "Widget '" << widgetName << "' (" << childWidget->metaObject()->className() << ") remains unmanaged.";
+//           qCDebug(KCONFIG_WIDGETS_LOG) << "Widget '" << widgetName << "' (" << childWidget->metaObject()->className() << ") remains unmanaged.";
 //       }
 //     }
 // #endif
@@ -365,13 +364,13 @@ void KConfigDialogManager::updateWidgets()
 
         KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
         if (!item) {
-            qWarning() << "The setting '" << it.key() << "' has disappeared!";
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
             continue;
         }
 
         if (!item->isEqual(property(widget))) {
             setProperty(widget, item->property());
-//        qDebug() << "The setting '" << it.key() << "' [" << widget->className() << "] has changed";
+//        qCDebug(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' [" << widget->className() << "] has changed";
             changed = true;
         }
         if (item->isImmutable()) {
@@ -408,7 +407,7 @@ void KConfigDialogManager::updateSettings()
 
         KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
         if (!item) {
-            qWarning() << "The setting '" << it.key() << "' has disappeared!";
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
             continue;
         }
 
@@ -431,7 +430,7 @@ QByteArray KConfigDialogManager::getUserProperty(const QWidget *widget) const
         const QMetaProperty user = metaObject->userProperty();
         if (user.isValid()) {
             s_propertyMap()->insert(widget->metaObject()->className(), user.name());
-            //qDebug() << "class name: '" << widget->metaObject()->className()
+            //qCDebug(KCONFIG_WIDGETS_LOG) << "class name: '" << widget->metaObject()->className()
             //<< " 's USER property: " << metaProperty.name() << endl;
         } else {
             return QByteArray(); //no USER property
@@ -458,7 +457,7 @@ QByteArray KConfigDialogManager::getCustomProperty(const QWidget *widget) const
     QVariant prop(widget->property("kcfg_property"));
     if (prop.isValid()) {
         if (!prop.canConvert(QVariant::ByteArray)) {
-            qWarning() << "kcfg_property on" << widget->metaObject()->className()
+            qCWarning(KCONFIG_WIDGETS_LOG) << "kcfg_property on" << widget->metaObject()->className()
                        << "is not of type ByteArray";
         } else {
             return prop.toByteArray();
@@ -489,7 +488,7 @@ QByteArray KConfigDialogManager::getCustomPropertyChangedSignal(const QWidget *w
     QVariant prop(widget->property("kcfg_propertyNotify"));
     if (prop.isValid()) {
         if (!prop.canConvert(QVariant::ByteArray)) {
-            qWarning() << "kcfg_propertyNotify on" << widget->metaObject()->className()
+            qCWarning(KCONFIG_WIDGETS_LOG) << "kcfg_propertyNotify on" << widget->metaObject()->className()
                        << "is not of type ByteArray";
         } else {
             return prop.toByteArray();
@@ -529,7 +528,7 @@ void KConfigDialogManager::setProperty(QWidget *w, const QVariant &v)
         }
     }
     if (userproperty.isEmpty()) {
-        qWarning() << w->metaObject()->className() << " widget not handled!";
+        qCWarning(KCONFIG_WIDGETS_LOG) << w->metaObject()->className() << " widget not handled!";
         return;
     }
 
@@ -562,7 +561,7 @@ QVariant KConfigDialogManager::property(QWidget *w) const
         }
     }
     if (userproperty.isEmpty()) {
-        qWarning() << w->metaObject()->className() << " widget not handled!";
+        qCWarning(KCONFIG_WIDGETS_LOG) << w->metaObject()->className() << " widget not handled!";
         return QVariant();
     }
 
@@ -579,12 +578,12 @@ bool KConfigDialogManager::hasChanged() const
 
         KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
         if (!item) {
-            qWarning() << "The setting '" << it.key() << "' has disappeared!";
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
             continue;
         }
 
         if (!item->isEqual(property(widget))) {
-            // qDebug() << "Widget for '" << it.key() << "' has changed.";
+            // qCDebug(KCONFIG_WIDGETS_LOG) << "Widget for '" << it.key() << "' has changed.";
             return true;
         }
     }
